@@ -22,7 +22,7 @@ from rich.table import Table
 
 from ._exceptions import PerfplotError
 
-plt.style.use(matplotx.styles.dufte)
+plt.style.use(matplotx.styles.duftify(matplotx.styles.tab20r))
 
 # Orders of Magnitude for SI time units in {unit: magnitude} format
 si_time = {
@@ -62,12 +62,14 @@ class PerfplotData:
         flop,
         labels: list[str],
         xlabel: str | None,
+        title: str | None,
     ):
         self.n_range = np.asarray(n_range)
         self.timings_s = timings_s
         self.flop = flop
         self.labels = labels
         self.xlabel = xlabel
+        self.title = title
 
     def plot(  # noqa: C901
         self,
@@ -136,6 +138,8 @@ class PerfplotData:
 
         if self.xlabel:
             plt.xlabel(self.xlabel)
+        if self.title:
+            plt.title(self.title)
         if relative_to is not None and not logy:
             plt.gca().set_ylim(bottom=0)
 
@@ -214,6 +218,8 @@ class Bench:
         data = None
         if callable(self.setup):
             data = self.setup(n)
+            if not isinstance(data, tuple):
+                data = (data,)
 
         reference = None
         timings = []
@@ -226,6 +232,8 @@ class Bench:
 
             if isinstance(self.setup, list):
                 data = self.setup[k](n)
+                if not isinstance(data, tuple):
+                    data = (data,)
 
             # First let the function run once. The value is used for the equality_check
             # and the time for gauging how many more repetitions are to be done. If the
@@ -235,7 +243,7 @@ class Bench:
             # up first. The actual times are only reached after a few hundred
             # nanoseconds of computation. Most of the time it's okay though.
             t0_ns = time.perf_counter_ns()
-            val = kernel(data)
+            val = kernel(*data)
             t1_ns = time.perf_counter_ns()
             t_ns = t1_ns - t0_ns
 
@@ -257,7 +265,10 @@ class Bench:
                         if not is_equal:
                             raise PerfplotError(
                                 "Equality check failure. "
-                                + f"({self.labels[0]}, {self.labels[k]})"
+                                + f"{self.labels[0]}:\n"
+                                + f"{reference}:\n\n"
+                                + f"{self.labels[k]}:\n"
+                                + f"{val}:\n"
                             )
 
             # First try with one repetition only.
@@ -291,7 +302,7 @@ def _b(data, kernel: Callable, repeat: int):
     while min_timing_ns <= required_timing_ns:
         tm = np.array(
             timeit.repeat(
-                stmt=lambda: kernel(data),
+                stmt=lambda: kernel(*data),
                 repeat=repeat,
                 number=number,
                 timer=time.perf_counter_ns,
@@ -449,6 +460,7 @@ def bench(
     flops: Callable | None = None,
     labels: list[str] | None = None,
     xlabel: str | None = None,
+    title: str | None = None,
     target_time_per_measurement: float = 1.0,
     max_time: float | None = None,
     equality_check: Callable | None = np.allclose,
@@ -504,7 +516,7 @@ def bench(
             timings_s = timings_s[:i]
             n_range = n_range[:i]
 
-    return PerfplotData(n_range, timings_s.T, flop, labels, xlabel)
+    return PerfplotData(n_range, timings_s.T, flop, labels, xlabel, title)
 
 
 # For backward compatibility:
